@@ -18,7 +18,6 @@ import platform
 import ctypes
 import time
 
-lib_dir = os.path.abspath(os.path.dirname(__file__))
 def _checkloaded():
     global _spinapi
     try:    
@@ -30,9 +29,8 @@ def _checkloaded():
         elif arch == ('64bit', 'WindowsPE'):
             libname = 'spinapi64.dll'
         else:
-            raise NotImplementedError("No Unix support yet - help me work out how to build a shared object from the Spincore API source and then it will be done.")
-        libpath = os.path.join(lib_dir, libname)
-        _spinapi = ctypes.cdll.LoadLibrary(libpath)
+            raise NotImplementedError("No Unix support yet - testing this would require building shared objects from the spincore API on linux, and I don't know how to do this.")
+        _spinapi = ctypes.cdll.LoadLibrary(libname)
         
 # Defines for different pb_inst instruction types
 CONTINUE = 0
